# Installation

This document describes installation only, for configuration of your project with CjkCMS, see [configuration](04.configuration.md)

You can install wagtail-cjkcms either from PyPI or from source. This will install all required dependencies into your current environment, including Wagtail and Django.

## Installing from PyPI

```bash
pip install wagtail-cjkcms
```

## Installing from source

```bash
pip install git+https://github.com/cjkpl/wagtail-cjkcms.git
```

## Installing as editable package, for development

Your editable package can sit anywhere in the filesystem, we prefer to use either a directory inside the django root project folder (e.g. `src` or `apps` for easiest testing - if you do it, remember to add that foler to `.gitignore`), or a directory parallel to the django project folder. See [testing](../unit_testing.md) for instructions on how to run tests.

```bash
git clone https://github.com/cjkpl/wagtail-cjkcms.git
cd wagtail-cjkcms
pip install - e.
```